==> jc-1.4.0.tar.gz: java/awt/font/FontRenderContext.h <==
// public class java.awt.font.FontRenderContext

// class file dependencies
// @dep_class 18db1274efda29ba java_awt_font_FontRenderContext
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_FontRenderContext_H_
#define _JC_java_awt_font_FontRenderContext_H_

// Forward structure declarations
struct _jc_java_awt_font_FontRenderContext$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_font_FontRenderContext$sub_refs	_jc_java_awt_font_FontRenderContext$sub_refs;
typedef struct _jc_java_awt_font_FontRenderContext$sub_nonrefs	_jc_java_awt_font_FontRenderContext$sub_nonrefs;
typedef struct _jc_java_awt_font_FontRenderContext$refs	_jc_java_awt_font_FontRenderContext$refs;
typedef struct _jc_java_awt_font_FontRenderContext$nonrefs	_jc_java_awt_font_FontRenderContext$nonrefs;
typedef struct _jc_java_awt_font_FontRenderContext$object	_jc_java_awt_font_FontRenderContext$object;

typedef const struct _jc_java_awt_font_FontRenderContext$vmethods	_jc_java_awt_font_FontRenderContext$vmethods;
typedef const struct _jc_java_awt_font_FontRenderContext$vtable	_jc_java_awt_font_FontRenderContext$vtable;
typedef const struct _jc_java_awt_font_FontRenderContext$vtype	_jc_java_awt_font_FontRenderContext$vtype;

// Constructors
extern void _jc_java_awt_font_FontRenderContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
extern void _jc_java_awt_font_FontRenderContext$method$_init$c8eb26d5835873c1(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_awt_geom_AffineTransform$object *, jboolean, jboolean);

// Virtual methods
extern jboolean _jc_java_awt_font_FontRenderContext$method$equals$4e224ae35ef582cc(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_awt_font_FontRenderContext$object *);
extern jboolean _jc_java_awt_font_FontRenderContext$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_awt_geom_AffineTransform$object *_jc_java_awt_font_FontRenderContext$method$getTransform$c5fe408eec532e13(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
extern jint _jc_java_awt_font_FontRenderContext$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
extern jboolean _jc_java_awt_font_FontRenderContext$method$isAntiAliased$0a6020f171f88b04(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
extern jboolean _jc_java_awt_font_FontRenderContext$method$usesFractionalMetrics$f0d7a6627c9c8d19(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$equals$4e224ae35ef582cc;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$getTransform$c5fe408eec532e13;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$isAntiAliased$0a6020f171f88b04;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$usesFractionalMetrics$f0d7a6627c9c8d19;

// Virtual methods structure
struct _jc_java_awt_font_FontRenderContext$vmethods {
	jboolean	(*equals$4e224ae35ef582cc)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_awt_font_FontRenderContext$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_awt_geom_AffineTransform$object	*(*getTransform$c5fe408eec532e13)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
	jboolean	(*isAntiAliased$0a6020f171f88b04)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
	jboolean	(*usesFractionalMetrics$f0d7a6627c9c8d19)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *);
};

// Vtable
struct _jc_java_awt_font_FontRenderContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_FontRenderContext$vmethods	java_awt_font_FontRenderContext;
};

// Vtype
struct _jc_java_awt_font_FontRenderContext$vtype {
	_jc_type			type;
	_jc_java_awt_font_FontRenderContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_FontRenderContext$sub_refs {
	struct _jc_java_awt_geom_AffineTransform$object	*affineTransform;
};

// Reference instance fields (object)
struct _jc_java_awt_font_FontRenderContext$refs {
    _jc_java_awt_font_FontRenderContext$sub_refs	java_awt_font_FontRenderContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_FontRenderContext$sub_nonrefs {
	jboolean	isAntiAliased;
	jboolean	usesFractionalMetrics;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_FontRenderContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_FontRenderContext$sub_nonrefs	java_awt_font_FontRenderContext;
};

// Object instance structure
struct _jc_java_awt_font_FontRenderContext$object {
	_jc_java_awt_font_FontRenderContext$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_FontRenderContext$vtype	*vtype;
	_jc_java_awt_font_FontRenderContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_FontRenderContext$vtype _jc_java_awt_font_FontRenderContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_FontRenderContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_FontRenderContext$class_object;

#endif	/* _JC_java_awt_font_FontRenderContext_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/FontRenderContext.h <==
// public class java.awt.font.FontRenderContext

// class file dependencies
// @dep_class 18db1274efda29ba java_awt_font_FontRenderContext
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_font_FontRenderContext_H_
#define _JC_java_awt_font_FontRenderContext_H_

// Forward structure declarations
struct _jc_java_awt_font_FontRenderContext$object;
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_font_FontRenderContext$sub_refs	_jc_java_awt_font_FontRenderContext$sub_refs;
typedef struct _jc_java_awt_font_FontRenderContext$sub_nonrefs	_jc_java_awt_font_FontRenderContext$sub_nonrefs;
typedef struct _jc_java_awt_font_FontRenderContext$refs	_jc_java_awt_font_FontRenderContext$refs;
typedef struct _jc_java_awt_font_FontRenderContext$nonrefs	_jc_java_awt_font_FontRenderContext$nonrefs;
typedef struct _jc_java_awt_font_FontRenderContext$object	_jc_java_awt_font_FontRenderContext$object;

typedef const struct _jc_java_awt_font_FontRenderContext$vmethods	_jc_java_awt_font_FontRenderContext$vmethods;
typedef const struct _jc_java_awt_font_FontRenderContext$vtable	_jc_java_awt_font_FontRenderContext$vtable;
typedef const struct _jc_java_awt_font_FontRenderContext$vtype	_jc_java_awt_font_FontRenderContext$vtype;

// Constructors
extern void _jc_java_awt_font_FontRenderContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_font_FontRenderContext$method$_init$c8eb26d5835873c1(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_awt_geom_AffineTransform$object *, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_awt_font_FontRenderContext$method$equals$4e224ae35ef582cc(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_font_FontRenderContext$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_geom_AffineTransform$object *_jc_java_awt_font_FontRenderContext$method$getTransform$c5fe408eec532e13(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_font_FontRenderContext$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_font_FontRenderContext$method$isAntiAliased$0a6020f171f88b04(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_font_FontRenderContext$method$usesFractionalMetrics$f0d7a6627c9c8d19(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$equals$4e224ae35ef582cc;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$getTransform$c5fe408eec532e13;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$isAntiAliased$0a6020f171f88b04;
extern _jc_method _jc_java_awt_font_FontRenderContext$method_info$usesFractionalMetrics$f0d7a6627c9c8d19;

// Virtual methods structure
struct _jc_java_awt_font_FontRenderContext$vmethods {
	jboolean	(*equals$4e224ae35ef582cc)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_geom_AffineTransform$object	*(*getTransform$c5fe408eec532e13)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
	jboolean	(*isAntiAliased$0a6020f171f88b04)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
	jboolean	(*usesFractionalMetrics$f0d7a6627c9c8d19)(_jc_env *, struct _jc_java_awt_font_FontRenderContext$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_FontRenderContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_FontRenderContext$vmethods	java_awt_font_FontRenderContext;
};

// Vtype
struct _jc_java_awt_font_FontRenderContext$vtype {
	_jc_type			type;
	_jc_java_awt_font_FontRenderContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_FontRenderContext$sub_refs {
	struct _jc_java_awt_geom_AffineTransform$object	*affineTransform;
};

// Reference instance fields (object)
struct _jc_java_awt_font_FontRenderContext$refs {
    _jc_java_awt_font_FontRenderContext$sub_refs	java_awt_font_FontRenderContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_FontRenderContext$sub_nonrefs {
	jboolean	isAntiAliased;
	jboolean	usesFractionalMetrics;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_FontRenderContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_FontRenderContext$sub_nonrefs	java_awt_font_FontRenderContext;
};

// Object instance structure
struct _jc_java_awt_font_FontRenderContext$object {
	_jc_java_awt_font_FontRenderContext$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_FontRenderContext$vtype	*vtype;
	_jc_java_awt_font_FontRenderContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_FontRenderContext$vtype _jc_java_awt_font_FontRenderContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_FontRenderContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_FontRenderContext$class_object;

#endif	/* _JC_java_awt_font_FontRenderContext_H_ */
